@@ -22,6 +22,9 @@ class ReinventCoreAdapter(GenerativeModelBase):
     def sample(self, batch_size):
         return self.generative_model.sample_sequences_and_smiles(batch_size)
 
+    def set_mode(self, mode: str):
+        self.generative_model.set_mode(mode)
+
     def get_network_parameters(self):
         return self.generative_model.get_network_parameters()
 
